# Changelog

## [0.2.0](https://github.com/equinor/rock-physics-open/compare/v0.1.3...v0.2.0) (2025-06-02)


### Features

* add support for Python 3.12 ([1de7cb3](https://github.com/equinor/rock-physics-open/commit/1de7cb318cbd0b8e01e54de1f8e9842ae32a4e17))


### Bug Fixes

* make get_snapshot_name more robust in search for calling function ([#31](https://github.com/equinor/rock-physics-open/issues/31)) ([e9e9ebd](https://github.com/equinor/rock-physics-open/commit/e9e9ebd8d9d101fa2a2bdd924f6f12be73476de7))

## [0.1.3](https://github.com/equinor/rock-physics-open/compare/v0.1.2...v0.1.3) (2025-05-13)


### Bug Fixes

* remove local version for scm ([d299b64](https://github.com/equinor/rock-physics-open/commit/d299b64c6cc6a75e0a17dabf105e0446be42a81d))
* initiate standardization of names for input parameters ([#25](https://github.com/equinor/rock-physics-open/issues/25)) ([3d505e3](https://github.com/equinor/rock-physics-open/commit/3d505e39e5e8130dcb9a16bf67fa22c96d47768a))
* standardize names of input parameters ([#27](https://github.com/equinor/rock-physics-open/issues/27)) ([55126fd](https://github.com/equinor/rock-physics-open/commit/55126fd8e2f3d51c9baad3fb5f55a6a2e0499c38))

## [0.1.2](https://github.com/equinor/rock-physics-open/compare/v0.1.1...v0.1.2) (2025-05-09)


### Bug Fixes

* avoid building deps wheels ([e188e9d](https://github.com/equinor/rock-physics-open/commit/e188e9d84d95bad08040dff5411b020c0af1426d))
* check release please output ([275f13e](https://github.com/equinor/rock-physics-open/commit/275f13e018af560d5459e8ac779825de517f0feb))
* use id for step to catch output value ([681c5e3](https://github.com/equinor/rock-physics-open/commit/681c5e3e36fd90dfc43c704a3298688ea6745e05))

## [0.1.1](https://github.com/equinor/rock-physics-open/compare/v0.1.0...v0.1.1) (2025-05-09)


### Bug Fixes

* use pip wheel to build wheels ([7c7b9f4](https://github.com/equinor/rock-physics-open/commit/7c7b9f405309ad8be3c76f91028260936d842b05))

## 0.1.0 (2025-05-08)


### Features

* initial release ([1ecc1c2](https://github.com/equinor/rock-physics-open/commit/1ecc1c2f0bff534bcdc007d4951865c4c37d5435))
